@@ -1,5 +1,3 @@
-import traceback
-
 from javonet.core.handler.AbstractHandler import AbstractHandler
 from javonet.core.handler.CommandHandler.ValueHandler import ValueHandler
 from javonet.core.handler.CommandHandler.LoadLibraryHandler import LoadLibraryHandler
@@ -19,10 +17,13 @@ from javonet.core.handler.CommandHandler.ArrayGetSizeHandler import ArrayGetSize
 from javonet.core.handler.CommandHandler.ArrayGetRankHandler import ArrayGetRankHandler
 from javonet.core.handler.CommandHandler.ArraySetItemHandler import ArraySetItemHandler
 from javonet.core.handler.CommandHandler.ArrayHandler import ArrayHandler
+from javonet.core.handler.CommandHandler.GetEnumItemHandler import GetEnumItemHandler
+from javonet.core.handler.CommandHandler.GetEnumNameHandler import GetEnumNameHandler
+from javonet.core.handler.CommandHandler.GetEnumValueHandler import GetEnumValueHandler
 
 from javonet.core.handler.HandlerDictionary import handler_dict
 from javonet.core.handler.ReferencesCache import ReferencesCache
-from javonet.core.exception.ExceptionSerializer import ExceptionSerializer
+from javonet.utils.exception.ExceptionSerializer import ExceptionSerializer
 from javonet.utils.CommandType import CommandType
 from javonet.utils.Command import Command
 
@@ -30,43 +31,29 @@ from javonet.utils.Command import Command
 class Handler(AbstractHandler):
 
     def __init__(self):
-        value_handler = ValueHandler()
-        load_library_handler = LoadLibraryHandler()
-        invoke_static_method_handler = InvokeStaticMethodHandler()
-        set_static_field_handler = SetStaticFieldHandler()
-        create_class_instance_handler = CreateClassInstanceHandler()
-        get_static_field_handler = GetStaticFieldHandler()
-        resolve_instance_handler = ResolveInstanceHandler()
-        get_type_handler = GetTypeHandler()
-        invoke_instance_method_handler = InvokeInstanceMethodHandler()
-        casting_handler = CastingHandler()
-        get_instance_field_handler = GetInstanceFieldHandler()
-        set_instance_field_handler = SetInstanceFieldHandler()
-        destruct_reference_handler = DestructReferenceHandler()
-        array_get_item_handler = ArrayGetItemHandler()
-        array_get_size_handler = ArrayGetSizeHandler()
-        array_get_rank_handler = ArrayGetRankHandler()
-        array_set_item_handler = ArraySetItemHandler()
-        array_handler = ArrayHandler()
 
-        handler_dict[CommandType.Value] = value_handler
-        handler_dict[CommandType.LoadLibrary] = load_library_handler
-        handler_dict[CommandType.InvokeStaticMethod] = invoke_static_method_handler
-        handler_dict[CommandType.SetStaticField] = set_static_field_handler
-        handler_dict[CommandType.CreateClassInstance] = create_class_instance_handler
-        handler_dict[CommandType.GetStaticField] = get_static_field_handler
-        handler_dict[CommandType.Reference] = resolve_instance_handler
-        handler_dict[CommandType.GetType] = get_type_handler
-        handler_dict[CommandType.InvokeInstanceMethod] = invoke_instance_method_handler
-        handler_dict[CommandType.Cast] = casting_handler
-        handler_dict[CommandType.GetInstanceField] = get_instance_field_handler
-        handler_dict[CommandType.SetInstanceField] = set_instance_field_handler
-        handler_dict[CommandType.DestructReference] = destruct_reference_handler
-        handler_dict[CommandType.ArrayGetItem] = array_get_item_handler
-        handler_dict[CommandType.ArrayGetSize] = array_get_size_handler
-        handler_dict[CommandType.ArrayGetRank] = array_get_rank_handler
-        handler_dict[CommandType.ArraySetItem] = array_set_item_handler
-        handler_dict[CommandType.Array] = array_handler
+        handler_dict[CommandType.Value] = ValueHandler()
+        handler_dict[CommandType.LoadLibrary] = LoadLibraryHandler()
+        handler_dict[CommandType.InvokeStaticMethod] = InvokeStaticMethodHandler()
+        handler_dict[CommandType.SetStaticField] = SetStaticFieldHandler()
+        handler_dict[CommandType.CreateClassInstance] = CreateClassInstanceHandler()
+        handler_dict[CommandType.GetStaticField] = GetStaticFieldHandler()
+        handler_dict[CommandType.Reference] = ResolveInstanceHandler()
+        handler_dict[CommandType.GetType] = GetTypeHandler()
+        handler_dict[CommandType.InvokeInstanceMethod] = InvokeInstanceMethodHandler()
+        handler_dict[CommandType.Cast] = CastingHandler()
+        handler_dict[CommandType.GetInstanceField] = GetInstanceFieldHandler()
+        handler_dict[CommandType.SetInstanceField] = SetInstanceFieldHandler()
+        handler_dict[CommandType.DestructReference] = DestructReferenceHandler()
+        handler_dict[CommandType.ArrayGetItem] = ArrayGetItemHandler()
+        handler_dict[CommandType.ArrayGetSize] = ArrayGetSizeHandler()
+        handler_dict[CommandType.ArrayGetRank] = ArrayGetRankHandler()
+        handler_dict[CommandType.ArraySetItem] = ArraySetItemHandler()
+        handler_dict[CommandType.Array] = ArrayHandler()
+        handler_dict[CommandType.GetEnumItem] = GetEnumItemHandler()
+        handler_dict[CommandType.GetEnumName] = GetEnumNameHandler()
+        handler_dict[CommandType.GetEnumValue] = GetEnumValueHandler()
+
 
     def handle_command(self, command):
         try:
