@@ -12,8 +12,9 @@ class GetInstanceFieldHandler < AbstractCommandHandler
   def get_instance_field(command)
     begin
       if command.payload.length != @required_parameters_count
-        raise "Instance field parameters mismatch"
+        raise ArgumentError.new "Instance field parameters mismatch"
       end
+
       merged_value = '@' + command.payload[1]
       if command.payload[0].instance_variable_defined?(merged_value)
         response = command.payload[0].instance_variable_get(merged_value)
@@ -21,6 +22,11 @@ class GetInstanceFieldHandler < AbstractCommandHandler
         raise "Instance field not defined"
       end
       return response
+    rescue NameError
+      fields = command.payload[0].instance_variables
+      message = "Field #{command.payload[1]} not found in object of class #{command.payload[0].class.name}. Available fields:\n"
+      fields.each { |field_iter| message += "#{field_iter}\n" }
+      raise Exception, message
     rescue Exception => e
       return e
     end
