@@ -27,10 +27,12 @@ class CommandType
   SET_INSTANCE_FIELD = 25
   INVOKE_GENERIC_STATIC_METHOD = 26
   INVOKE_GENERIC_METHOD = 27
-  CREATE_GENERIC_CLASS_INSTANCE = 28
-  GET_ENUM_ITEM = 29
-  GET_ENUM_NAME = 30
-  GET_ENUM_VALUE = 31
+  GET_ENUM_ITEM = 28
+  GET_ENUM_NAME = 29
+  GET_ENUM_VALUE = 30
+  AS_REF = 31
+  AS_OUT = 32
+  GET_REF_VALUE = 33
 
   def self.get_name(command_number)
     case command_number
@@ -91,13 +93,17 @@ class CommandType
     when 27
       return 'INVOKE_GENERIC_METHOD'
     when 28
-      return 'CREATE_GENERIC_CLASS_INSTANCE'
-    when 29
       return 'GET_ENUM_ITEM'
-    when 30
+    when 29
       return 'GET_ENUM_NAME'
-    when 31
+    when 30
       return 'GET_ENUM_VALUE'
+    when 31
+	  return 'AS_REF'
+    when 32
+	  return 'AS_OUT'
+    when 33
+	  return 'GET_REF_VALUE'
     end
   end
 end
\ No newline at end of file
