@@ -27,8 +27,8 @@ sub process {
             die Exception->new("Exception: ArraySetItemHandler parameters mismatch");
         }
         my $array = $command->{payload}[0];
-        my $value = $command->{payload}[1];
-        my @indexes = $command->{payload}[2,];
+        my @indexes = $command->{payload}[1];
+        my $value = $command->{payload}[2];
 
         @{$array}[@indexes] = $value;
         return 0;
